@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/DateTime.pm
-## Version v0.2.0
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.2.1
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2022/02/27
+## Modified 2022/03/06
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -17,8 +17,9 @@ BEGIN
     use warnings;
     use parent qw( Module::Generic );
     use vars qw( $ERROR $TS_RE );
-    use DateTime;
-    use DateTime::Format::Strptime;
+    use DateTime 1.57;
+    use DateTime::Format::Strptime 1.79;
+    use DateTime::TimeZone 2.51;
     use Nice::Try dont_want => 1;
     use Regexp::Common;
     use Scalar::Util ();
@@ -56,7 +57,7 @@ BEGIN
         )?
     )?
     /x;
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 # use strict;
@@ -675,7 +676,7 @@ Module::Generic::DateTime - A DateTime wrapper for enhanced features
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
